import React, { useState, useEffect } from 'react'
import { Layout, Menu } from 'antd'
import { Route } from 'react-router-dom'
import { MehOutlined } from '@ant-design/icons'
import './index.scss'
import '@ant-design/pro-table/dist/table.css'
import { routes } from  '../router/config'


const { Header, Content, Sider } = Layout
// 路由渲染
const reallyRoutes = routes.map(item => item.children ? [item, ...item.children] : item).flat()

const AdminLayout: any = (props: any) => {
  const [currentKeys, setCurrentKeys]: any = useState(["/admin/role"])

  const switchRoute = route => {
    props.history.push(route.path)
    setCurrentKeys([route.path])
  }
  useEffect(() => {
    setCurrentKeys([props.history.location.pathname])
  }, [props.history.location.pathname])

  return (
    <Layout style={{ minHeight: '100vh' }}>
      <Sider style={{
        overflow: 'auto',
        height: '100vh',
        position: 'fixed',
        left: 0,
        background: 'white'
      }}>
        <Menu mode="inline" selectedKeys={currentKeys}>
        {
          routes.filter(item => !item.hideInMenu).map((route) => {
            return (
              route.children && route.children.filter(({ hideInMenu }) => !hideInMenu)?.length
                ?
                <Menu.SubMenu key={route.path} title={route.title}>
                  {
                    route.children.filter(item => !item.hideInMenu).map(child =>
                      <Menu.Item
                        key={child.path}
                        onClick={() => switchRoute(child)}
                      >
                        {child.title}
                      </Menu.Item>
                    )
                  }
                </Menu.SubMenu>
                :
                <Menu.Item
                  key={route.path}
                  onClick={() => switchRoute(route)}>
                  {route.title}
                </Menu.Item>
            )
          })
        }
        </Menu>
      </Sider>
      <Layout style={{ marginLeft: 200 }}>
        <Header className='layout-header'>
          物业管理系统 System
          <div>
            <MehOutlined/> Admin
          </div>
        </Header>
        <Content className='layout-content'>
          {
            reallyRoutes.map((route: any) =>
                <Route
                  exact={route.exact}
                  path={route.path}
                  key={route.path}
                  component={route.component}
                />
            )
          }
        </Content>
      </Layout>
    </Layout>
  )
}

export default AdminLayout