import HomePage from '../views/Home/index'
import Login2 from '../views/User/Login'
import React, { lazy, Suspense } from 'react'

const OwnerList = lazy(() => import('../views/Owner/index'))
const OwnerExamine = lazy(() => import('../views/Owner/examine'))
const CompanyInfo = lazy(() => import('../views/Settings/info'))
const Neighbor = lazy(() => import('../views/Service/neighbor'))
const PageList = lazy(() => import('../views/Service/page-list'))
const Comments = lazy(() => import('../views/Service/comments'))
const Notice = lazy(() => import('../views/Service/notice'))
const Activity = lazy(() => import('../views/Service/activity'))
const ChargeSetup = lazy(() => import('../views/Charge/setup'))
// 绑定房屋
const ChargeSetupBindRoom = lazy(() => import('../views/Charge/setup-bind-room'))
// 绑定汽车
const ChargeSetupBindCar = lazy(() => import('../views/Charge/setup-bind-car'))
// 绑定车位
const ChargeSetupBindParking = lazy(() => import('../views/Charge/setup-bind-parking'))
// 房屋收费
const HouseCharge = lazy(() => import('../views/Charge/house'))
// 抄表管理
const Meter = lazy(() => import('../views/Charge/meter'))


// 停车设置
// 车辆管理
const ParkingCar = lazy(() => import('../views/Parking/Car'))
// 停车场管理
const ParkingList = lazy(() => import('../views/Parking/list'))
// 停车位管理
const ParkingPosition = lazy(() => import('../views/Parking/position'))

// 楼盘管理
// 房屋管理
const BuildingHouse = lazy(() => import('../views/building/house'))
// 楼栋管理
const Buildings = lazy(() => import('../views/building/list'))
// 单元管理
const BuildingUnit = lazy(() => import('../views/building/unit'))



// 房屋租赁
const House = lazy(() => import('../views/House/index'))
// 创建房屋租赁
const HouseLeaseCreate = lazy(() => import('../views/House/lease-create'))
const HouseLeaseManager = lazy(() => import('../views/House/lease-manager'))
const HouseLease = lazy(() => import('../views/House/lease'))
// 房屋收费-明细
const HouseArrears = lazy(() => import('../views/Charge/house-arrears'))
// 房屋收费-账单明细
const HouseBill = lazy(() => import('../views/Charge/house-bill'))
// 房屋收费-账单明细-缴费
const HouseBillHandle = lazy(() => import('../views/Charge/bill-handle'))
// 房屋收费-账单明细-预存
const HouseBillPrestore = lazy(() => import('../views/Charge/bill-prestore'))

// 车辆收费
const CarCharge = lazy(() => import('../views/Charge/car'))
// 车辆收费-查看费用
const CarChargeBill = lazy(() => import('../views/Charge/car-bill'))
// 车位收费
const ChargeParkingPosition = lazy(() => import('../views/Charge/parking-position'))
// 车位收费-查看费用
const ChargeParkingPositionBill = lazy(() => import('../views/Charge/parking-position-bill'))

// 预缴设置
const Arrears = lazy(() => import('../views/Charge/arrears'))
// 收费设置
const ChargeSetting = lazy(() => import('../views/Charge/setting'))
// 应付账单
const ShouldBill = lazy(() => import('../views/Charge/should-bill'))
// 已缴账单
const PayBill = lazy(() => import('../views/Charge/payed-bill'))
// 废弃账单
const ScrapBill = lazy(() => import('../views/Charge/scrap-bill'))
// 缴费账单
const PaymentBill = lazy(() => import('../views/Charge/payment-bill'))

//用户管理
// 权限组
const UserRoles = lazy(() => import('../views/User/roles'))
// 用户
const UserList = lazy(() => import('../views/User/account'))


// 报事报修相关
const FixType = lazy(() => import('../views/Fix/type'))
const FixOnlineForm = lazy(() => import('../views/Fix/online-form'))
const FixReturnVisit = lazy(() => import('../views/Fix/return-visit'))
const FixTodo = lazy(() => import('../views/Fix/to-do'))
const FixOrderDetail = lazy(() => import('../views/Fix/order-detail'))

// 投诉相关
const Complaint = lazy(() => import('../views/Complaint/index'))
const ComplaintHandle = lazy(() => import('../views/Complaint/handle'))
const ComplaintReturnVisit = lazy(() => import('../views/Complaint/return-visit'))
const ComplaintDetail = lazy(() => import('../views/Complaint/order-detail'))

export const Wrapper = (Component) => (props) => {
  return (
    <Suspense fallback={() => {}}>
      <Component/>
    </Suspense>
  )
}

export const routes: any = [
  {
    title: '系统首页',
    path: '/admin/index',
    component: HomePage,
  },
  {
    title: '住户管理',
    path: '/admin/owner',
    exact: true,
    children: [
      {
        title: '住户信息',
        path: '/admin/owner/info',
        exact: true,
        component: Wrapper(OwnerList)
      },
      {
        title: '住户审核',
        path: '/admin/owner/examine',
        exact: true,
        component: Wrapper(OwnerExamine)
      },
    ]
  },
  {
    title: '楼盘管理',
    exact: true,
    children: [
      {
        title: '楼栋管理',
        path: '/admin/building/list',
        component: Wrapper(Buildings)
      },
      {
        title: '单元管理',
        path: '/admin/building/unit',
        component: Wrapper(BuildingUnit)
      },
      {
        title: '房屋管理',
        path: '/admin/building/house',
        component: Wrapper(BuildingHouse)
      }
    ]
  },
  {
    title: '小区服务',
    path: '/admin/service',
    exact: true,
    children: [
      {
        title: '社区邻里',
        path: '/admin/service/neighbor',
        exact: true,
        component: Wrapper(Neighbor)
      },
      {
        title: '文章列表',
        path: '/admin/service/page-list',
        exact: true,
        hideInMenu: true,
        component: Wrapper(PageList)
      },
      {
        title: '评论列表',
        path: '/admin/service/comments',
        exact: true,
        hideInMenu: true,
        component: Wrapper(Comments)
      },
      {
        title: '公告通知',
        path: '/admin/service/notice',
        exact: true,
        component: Wrapper(Notice)
      },
      {
        title: '社区活动',
        path: '/admin/service/activity',
        exact: true,
        component: Wrapper(Activity)
      },
    ]
  },
  {
    title: '停车管理',
    path: '/admin/parking',
    exact: true,
    children: [
      {
        title: '停车场管理',
        path: '/admin/parking/manager',
        exact: true,
        component: Wrapper(ParkingList)
      },
      {
        title: '车位管理',
        path: '/admin/parking/position',
        exact: true,
        component: Wrapper(ParkingPosition)
      },
      {
        title: '业主车辆',
        path: '/admin/car',
        exact: true,
        component: Wrapper(ParkingCar)
      },
      // {
      //   title: '进出场记录',
      //   path: '/admin/parking/record',
      //   exact: true,
      //   component: Wrapper(OwnerExamine)
      // },
      // {
      //   title: '黑白名单',
      //   path: '/admin/parking/list',
      //   exact: true,
      //   component: Wrapper(OwnerExamine)
      // }
    ]
  },
  {
    title: '收费管理',
    path: '/admin/charge',
    exact: true,
    children: [
      {
        title: '抄表管理',
        path: '/admin/charge/meter',
        exact: true,
        component: Wrapper(Meter)
      },
      {
        title: '费用设置',
        path: '/admin/charge/setup',
        exact: true,
        component: Wrapper(ChargeSetup)
      },
      {
        title: '绑定房屋',
        path: '/admin/charge/setup-room',
        exact: true,
        hideInMenu: true,
        component: Wrapper(ChargeSetupBindRoom)
      },
      {
        title: '绑定汽车',
        path: '/admin/charge/setup-car',
        exact: true,
        hideInMenu: true,
        component: Wrapper(ChargeSetupBindCar)
      },
      {
        title: '绑定车位',
        path: '/admin/charge/setup-parking',
        exact: true,
        hideInMenu: true,
        component: Wrapper(ChargeSetupBindParking)
      },
      {
        title: '房屋收费',
        path: '/admin/charge/house',
        exact: true,
        component: Wrapper(HouseCharge)
      },
      {
        title: '房屋收费-欠费',
        path: '/admin/charge/house-arrears',
        exact: true,
        hideInMenu: true,
        component: Wrapper(HouseArrears)
      },
      {
        title: '房屋收费-费用明细',
        path: '/admin/charge/house-bill',
        exact: true,
        hideInMenu: true,
        component: Wrapper(HouseBill)
      },
      {
        title: '收费-预存',
        path: '/admin/charge/prestore',
        exact: true,
        hideInMenu: true,
        component: Wrapper(HouseBillPrestore)
      },
      {
        title: '房屋收费-费用缴费',
        path: '/admin/charge/house-bill/handle',
        exact: true,
        hideInMenu: true,
        component: Wrapper(HouseBillHandle)
      },
      {
        title: '车辆收费',
        path: '/admin/car/cost',
        exact: true,
        component: Wrapper(CarCharge)
      },
      {
        title: '车辆收费-查看费用',
        path: '/admin/car/bill',
        exact: true,
        hideInMenu: true,
        component: Wrapper(CarChargeBill)
      },
      {
        title: '车位收费',
        path: '/admin/charge/parking-position',
        exact: true,
        component: Wrapper(ChargeParkingPosition)
      },
      {
        title: '车位收费-查看费用',
        path: '/admin/charge/parking-position/bill',
        exact: true,
        hideInMenu: true,
        component: Wrapper(ChargeParkingPositionBill)
      },
      {
        title: '物业费预缴设置',
        path: '/admin/arrears',
        exact: true,
        component: Wrapper(Arrears)
      },
      {
        title: '收费设置',
        path: '/admin/charge/setting',
        exact: true,
        component: Wrapper(ChargeSetting)
      },
      {
        title: '应收账单',
        path: '/admin/charge/should-bill',
        exact: true,
        component: Wrapper(ShouldBill)
      },
      {
        title: '已缴账单',
        path: '/admin/charge/payed-bill',
        exact: true,
        component: Wrapper(PayBill)
      },
      {
        title: '废弃账单',
        path: '/admin/charge/scrap-bill',
        exact: true,
        component: Wrapper(ScrapBill)
      },
      {
        title: '缴费账单',
        path: '/admin/charge/payment-bill',
        exact: true,
        component: Wrapper(PaymentBill)
      },
    ]
  },
  {
    title: '用户管理',
    path: '/admin/account',
    exact: true,
    children: [
      {
        title: '权限组',
        path: '/admin/account/roles',
        exact: true,
        component: Wrapper(UserRoles)
      },
      {
        title: '用户',
        path: '/admin/account/list',
        exact: true,
        component: Wrapper(UserList)
      }
    ]
  },
  {
    title: '报事报修',
    path: '/admin/fix',
    exact: true,
    children: [
      {
        title: '报修类型',
        path: '/admin/fix/type',
        exact: true,
        component: Wrapper(FixType)
      },
      {
        title: '在线报修',
        path: '/admin/fix/online',
        exact: true,
        component: Wrapper(FixOnlineForm)
      },
      {
        title: '报修订单详情',
        path: '/admin/fix/order-detail',
        exact: true,
        component: Wrapper(FixOrderDetail),
        hideInMenu: true
      },
      {
        title: '报修待办',
        path: '/admin/fix/dealt',
        exact: true,
        component: Wrapper(FixTodo)
      },
      {
        title: '报修回访',
        path: '/admin/fix/return-visit',
        exact: true,
        component: Wrapper(FixReturnVisit)
      }
    ]
  },
  {
    title: '投诉建议',
    path: '/admin/complaint',
    exact: true,
    children: [
      {
        title: '投诉建议详情',
        path: '/admin/complaint/detail',
        exact: true,
        component: Wrapper(ComplaintDetail),
        hideInMenu: true
      },
      {
        title: '投诉录入',
        path: '/admin/complaint',
        exact: true,
        component: Wrapper(Complaint),
      },
      {
        title: '投诉受理',
        path: '/admin/complaint/handle',
        exact: true,
        component: Wrapper(ComplaintHandle),
      },
      {
        title: '投诉回访',
        path: '/admin/complaint/return-visit',
        exact: true,
        component: Wrapper(ComplaintReturnVisit),
      },
    ]
  },
  {
    title: '房屋租售',
    path: '/admin/house',
    exact: false,
    component: Wrapper(House),
    children: [
      {
        title: '房屋租赁',
        path: '/admin/house/lease',
        exact: true,
        component: Wrapper(HouseLease)
      },
      {
        title: '房屋管理',
        path: '/admin/house/manager',
        exact: true,
        hideInMenu: true,
        component: Wrapper(HouseLeaseManager)
      },
      {
        title: '房屋租赁-创建',
        path: '/admin/house/lease-create',
        exact: true,
        hideInMenu: true,
        component: Wrapper(HouseLeaseCreate)
      },
      {
        title: '房屋出售',
        path: '/admin/house/sell',
        exact: true,
        component: Wrapper(OwnerExamine)
      },
      {
        title: '车位租赁',
        path: '/admin/parking/lease',
        exact: true,
        component: Wrapper(OwnerExamine)
      },
      {
        title: '车位出售',
        path: '/admin/parking/sell',
        exact: true,
        component: Wrapper(OwnerExamine)
      },
    ]
  },
  {
    title: '系统设置',
    path: '/admin/setting',
    exact: true,
    children: [
      {
        title: '小区信息',
        path: '/admin/setting/info',
        exact: true,
        component: Wrapper(CompanyInfo)
      }
    ]
  },
  {
    title: '客服IM',
    path: '/admin/customer/service',
    exact: true,
    component: Wrapper(CompanyInfo)
  }
]

export const staticRoutes = [
  {
    title: '登录',
    path: '/login',
    component: Login2
  }
]
