import React, { FC } from 'react'
import { Card, Row, Col, Divider } from "antd"
import { GetStatisticsData } from "../../services/statistics"
import { Column } from '@antv/g2plot'
import "./index.scss"

const HomePage: FC = any => {

  const [totalData, setTotalData]: any = React.useState({})
  const [totalItems, setTotalItems] = React.useState({
    user_count: {
      title: '住户人数',
      count: 100,
      describe: '小区当前已入住住户人数',
      color: '#db5050'
    },
    house_count: {
      title: '房屋数量',
      count: 100,
      describe: '小区当前房屋总数',
      color: 'rgb(219 157 80)'
    },
    space_count: {
      title: '车位数量',
      count: 100,
      describe: '小区车位总数',
      color: 'rgb(104 197 158)'
    },
    vehicle_count: {
      title: '车辆数量',
      count: 100,
      describe: '小区已登记车辆总数',
      color: 'rgb(83 152 211)'
    },
  })

  React.useEffect(() => {
    GetStatisticsData().then(({ data }) => setTotalData(data))
    initChart()
  }, [])

  const initChart = () => {
    const data = [
      {
        name: 'London',
        month: '1月',
        value: 18.9,
      },
      {
        name: 'London',
        month: '2月',
        value: 28.8,
      },
      {
        name: 'London',
        month: '3月',
        value: 39.3,
      },
      {
        name: 'London',
        month: '4月',
        value: 81.4,
      },
      {
        name: 'London',
        month: '5月',
        value: 47,
      }
    ]

    const stackedColumnPlot = new Column('line-chart', {
      data,
      isGroup: true,
      xField: 'month',
      yField: 'value',
      seriesField: 'name',
      /** 设置颜色 */
      //color: ['#1ca9e6', '#f88c24'],
      /** 设置间距 */
      // marginRatio: 0.1,
      label: {
        // 可手动配置 label 数据标签位置
        position: 'middle', // 'top', 'middle', 'bottom'
        // 可配置附加的布局方法
        layout: [
          // 柱形图数据标签位置自动调整
          { type: 'interval-adjust-position' },
          // 数据标签防遮挡
          { type: 'interval-hide-overlap' },
          // 数据标签文颜色自动调整
          { type: 'adjust-color' },
        ],
      },
    });

    stackedColumnPlot.render();
  }

  return (
    <Card title="系统设置/首页">
      <Row justify="space-between" className="pl-10 pr-10">
        { Object.keys(totalItems).map(key => (
          <Col span={5}>
            <div className="total-block" style={{ backgroundColor: totalItems[key]?.color }}>
              <div className="total-title">{ totalItems[key]?.title }</div>
              <div className="total-count">{ totalData[key] || totalItems[key].count  }</div>
              { totalItems[key]?.describe  }
            </div>
          </Col>
        )) }
      </Row>
      <Divider/>
      <Card title="待办已办">
        <div style={{ height: 440 }} id="line-chart"/>
      </Card>
    </Card>
  )
}

export default HomePage