import React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, InputNumber, message } from 'antd'
import { withRouter } from 'react-router-dom'
import { Building } from '../../services/building'
import './index.scss'

const BuildingList: React.FC = (props: any) => {
  const columns: any = [
    {
      title: 'ID',
      dataIndex: 'id',
      search: false
    },
    {
      title: '楼栋编号',
      dataIndex: 'building_number',
      search: true,
    },
    {
      title: '楼栋名',
      dataIndex: 'building_name',
      search: false,
    },
    {
      title: '单元数',
      dataIndex: 'unit_count',
      search: false,
    },
    {
      title: '是否存在单元',
      dataIndex: 'unit_count',
      search: false,
      render: (_, record: any) => <span>{ record.unit_count ? '是' : '否' }</span>
    },
    {
      title: '建筑面积',
      dataIndex: 'building_area',
      search: false,
    },
    {
      title: '使用面积',
      dataIndex: 'building_used_area',
      search: false,
    },
    {
      title: '备注',
      dataIndex: 'comment',
      search: false,
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      render: (_, row, index, action) => {
        return [
          <Button onClick={() => {
            form.setFieldsValue(row)
            setState(prevState => ({ ...prevState, visible: true, editId: row.id }))
          }}>编辑</Button>,
          <Button onClick={() => {
            Modal.confirm({
              title: '删除记录',
              content: '你确定删除这条记录吗？',
              onOk: async () => {
                await Building({ method: 'delete', id: row.id })
                message.success('操作成功！')
                actionRef.current.reload()
              }
            })
          }}>删除</Button>,
          <Button onClick={() => {
            props.history.push('/admin/building/unit')
          }}>添加单元</Button>
        ]
      }
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    editId: null
  })
  const actionRef: any = React.useRef<ActionType>()
  const [form] = Form.useForm()
  const onSubmit = () => {
    form.validateFields().then(async values => {
      await Building({
        ...values,
        method: state.editId ? 'put' : 'post',
        id: state.editId
      })
      message.success('操作成功！')
      actionRef.current?.reloadAndRest()
      setState(prevState => ({ ...prevState, visible: false }))
    })
  }

  return (
    <React.Fragment>
      <ProTable
        headerTitle="楼盘管理/楼栋管理"
        actionRef={actionRef}
        rowKey="key"
        request={Building}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              form.resetFields()
              setState(preState => ({ visible: true, editId: null }))
            }}
          >添加</Button>
        ]}
        columns={columns}
      />
      <Modal
        title={state.editId? "编辑楼栋": "添加楼栋"}
        visible={state.visible}
        width={680}
        onOk={onSubmit}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form
          labelCol={{ span: 5 }}
          wrapperCol={{ span: 15 }}
          form={form}
        >
          <Form.Item label='楼栋编号' name="building_number" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='楼栋名' name="building_name" rules={[{ required: true }]}>
            <Input placeholder="请输入" />
          </Form.Item>
          <Form.Item label='建筑面积' name="building_area" rules={[{ required: true }]}>
            <InputNumber placeholder="请输入" />
          </Form.Item>
          <Form.Item label='使用面积' name="building_used_area" rules={[{ required: true }]}>
            <InputNumber placeholder="请输入" />
          </Form.Item>
          <Form.Item label='备注' name="comment" rules={[{ required: true }]}>
            <Input.TextArea rows={4} placeholder="请输入" />
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default withRouter(BuildingList)